## Changelog for vue-autoNumeric

### 1.2.0
+ Simplify how the `rawValue` decimal places are set
  + In `v1.1.*`, whenever the options were changed, the number of decimal places for the `rawValue` was calculated based of the previous options, and not only the new given options.
  + This was useful when two vue-autonumeric components shared the same v-model, but different options that have different values for the `rawValue` decimal places count.
  + For instance if one of the `vue-autonumeric` component had a `decimalPlaces` option set to `2`, and another set to `5`, then when the user modified the value of one of those components, vue-autonumeric would detect a programmatic value change in the other component (since it did not come from a user interaction), and it would then use `set()` to set the new value.
  + The first component would drop the additional decimal places when using `set()`...which in turn would make the other components aware of that new value change, and the second component would then use that new cropped value as well.
  + However, this special decimal places management is complexifying the code quite a bit, and is not 100% effective since some use cases were difficult, if even possible, to manage.
  + This `rawValueDecimalPlaces` *hack* is now reverted to a more sane and legible code.
  + From now on, the user will have to explicitly declare the `rawValueDecimalPlaces` value when updating the options, if he does not want to lose the precision when switching options.
+ Fix the case of the AutoNumeric import name in the webpack configuration

### 1.1.0
+ Fix issue #10 When using an object to modify both the `:value` and `:options` props, the options is not always modified before the value
+ Fix the issue where updating the `options` to new ones with a higher `decimalPlacesRawValue` loses the additional decimal places
+ Now allows to update the `options` by passing an array of options (with objects and predefined option names)
+ When the `options` and `value` are both set at the same time, `vue-autonumeric` now always update the `options` first, before setting the `value`.
  + This allows to use objects with the value and a predefined option name to modify the vue-autonumeric component.
  + Note: There is a known bug; if you use multiple `vue-autonumeric` component sharing the same `v-model` but *different* options, changing the value/option *may* not work correctly.
    + This is due to the fact that when vue-autonumeric detects a value change, it `set()` it since it does not come from a user interaction.
    + However if one of the `vue-autonumeric` component has a `decimalPlaces` option set to `2`, and another set to `5`, then the first component will drop the additional decimal places when using `set()`...which in turn will make the other component aware of that new value change, and the second component will then use that new cropped value as well.

### 1.0.7
+ Fix issue #9 Modifying the `options` will always lose the decimal places precision after `2` places
  + This happens since `resetOnOptions` temporarily resets the configuration to the default one, which set the `decimalPlaces` option to `2`.

### 1.0.6
+ Fix issue #8 Add a new `resetOnOptions` props so that updating the `options` one first reset to the default options
+ Add a `resetOnOptions` props set the `true` by default so that updating the `options` prop first call `.options.reset()`
  + This is useful when using predefined option names that do not declare all the options. For instance when switching from `'integer'` to `'euro'`, the `decimalPlaces` was not set from `0` to `2` and you had to first update to the default configuration.
  + Now by default all options update will reset to the default options first. This can be avoided by setting `resetOnOptions` to false before changing the `options` value.

### 1.0.5
+ Fix issue #2 Allow the component to generate any supported Html element instead of only `<input>`

### 1.0.4
+ Fix the component size issue which bundled the whole `AutoNumeric` library
+ Update the documentation with how to install the component, depending if the AutoNumeric library should be bundled or not

### 1.0.3
+ Fix importing issues with the `AutoNumeric` library
+ Complete the documentation on how to install and use the component
+ Add a link to the examples page and its source in the Readme
+ Fix the example script imports by removing the unneeded AutoNumeric link
+ Fix issue #4 Error when building with webpack 2 on linux

### 1.0.2
+ Fix issue #3 Update the value when the `:options` prop is modified

### 1.0.1
+ Rename the component source from `Autonumeric` to `VueAutonumeric` to prevent confusion with the `AutoNumeric` library
+ Update the examples source accordingly
+ Update the readme with badges
+ Update the readme with more detailed installation instructions
+ Fix the examples in the readme and update the Codepen link

### 1.0.0
+ Release the version `v1.0.0` of the vue-autoNumeric component
